@@ -53,5 +53,16 @@ Returns true or false, if the current connection has been aborted or not - respe
 
 Returns an instance of L<ASP4::Mock::ClientSocket>.
 
+=head1 BUGS
+
+It's possible that some bugs have found their way into this release.
+
+Use RT L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=ASP4> to submit bug reports.
+
+=head1 HOMEPAGE
+
+Please visit the ASP4 homepage at L<http://0x31337.org/code/> to see examples
+of ASP4 in action.
+
 =cut
 
